Playmanity.py
=======================================
Playmanity.py is a Python library for using and creating api scripts & programs with integration of playmanity services. We use official playmanity api